AsyncWriterFutureLen

Trait AsyncWriterFutureLen 

pub trait AsyncWriterFutureLen<W: AsyncWrite>: AsyncWriterFuture<W> {
    // Required method
    fn remaining_bytes(&self) -> usize;
}
👎Deprecated:

This was a failed attempt at finding a suitable abstraction. The async-codec crate might be what you need instead.

Base trait for futures that write things into AsyncWrites and can precompute the exact number of bytes to write.

Required Methods

fn remaining_bytes(&self) -> usize

👎Deprecated:

This was a failed attempt at finding a suitable abstraction. The async-codec crate might be what you need instead.

Compute the exact number of bytes that will still be written by this future.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors